# ---------------------------------------------------------------------------------------------------------------------
# Este script 1) Crear un archivo espacial con los datos del calculo de biomasa en campo y sus coordenadas. 
#             2) Extraccion de valores de las metricas de textuta basa en la unicacion de las parcelas de campo
#             3) Extraccion valores promedio de retrodispersion (HH, HV y NDBI) en una hectarea. 
# 
# Instalar los paquetes:
# # raster, sp, spatial.tools, sf.
#------------------------------------------------------------------------------------------------------------------------
#
# PASO 1: CREAR UN ARCHIVO ESPACIAL CON LA BASE DE DATOS DE CAMPO
#-------------------------------------------------------------------------------
#
# Definir el directorio de trabajo
setwd(choose.dir( default = ".", caption = "Seleccione el directorio de trabajo"))
getwd()
folder <- getwd()

library(sp)
library(raster)
library(sf)

# Cargar el archivo que contenga las coordenadas
data <- read.csv(choose.files(
  caption = "Selecciona el archivo de coordenadas en formato CSV"),
  header = TRUE,
  sep = ",")
names(data)

# convertir data frame to spatial feature
#asignar las coordenadas nativas de los puntos
points <- st_as_sf(data,coords = c("X_mean", "Y_mean"),
                   # definir la proyeccion nativa
                   crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs"
                   )
summary(points)
plot(points[,7])

# nueva proyeccion de coordenadas # Mexico ITRF2008/LCC EPSG: 6372
newProj <- "+proj=lcc +lat_1=17.5 +lat_2=29.5 +lat_0=12 +lon_0=-102 +x_0=2500000 +y_0=0 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
points <- st_transform(points, newProj)

plot(points[,7])


# PASO 2: EXTRAER VALORES DE LAS TEXTURAS USANDO LOS PUNTOS
#-------------------------------------------------------------------------------
# Cargar directorio de imagenesse archivos de texturas
dir.IMG_textura <- choose.dir(
  caption = "Seleccione el directorio de los archivos de texturas")

# Listas archivos raster
ListIMG_texturas <- list.files(path = dir.IMG_textura, pattern = ".img$",
                                      full.names = TRUE)
ListIMG_texturas

# stack de los archivos raster
texturs <- stack(ListIMG_texturas)
texturs

plot(texturs$HH_cont, legend= FALSE)
plot(points[,7], add = TRUE)

# Extraer valores de texturas por punto central
data.p <- extract(texturs, points,
                  method = "simple",
                  df = TRUE,  sp = TRUE)
summary(data.p)


# PASO 3: EXTRAER DATOS DE LAS POLARIZACIONES
#-------------------------------------------------------------------------------
# Cargar directorio de imagenes de archivos backscatter
dir.IMG_bcks <- choose.dir(
  caption = "Seleccione el directorio de los archivos Backscatter y NDBI")

# Listas archivos raster 
ListIMG_bcks <- list.files(path = dir.IMG_bcks, pattern = ".img$",
                             full.names = TRUE)
ListIMG_bcks

# stack de los archivos raster
bcks <- stack (ListIMG_bcks)
bcks

plot(bcks$HH , legend= FALSE)
plot(points[,7], add = TRUE)


# Extraer valores promedio de backstactter en un Ha
points <- st_as_sf(data.p)
# Generar poligonos por buffer
points_buffer <- st_buffer(points, 56.41895835)
plot(points_buffer[,7])

data.b <- extract(bcks, points_buffer,
        fun = mean,
        na.rm= TRUE,
        sp = TRUE)

summary(data.b)

# PASO 4: CONVERTIR LOS DATOS ESPACIALES A DATAFRAME Y GRABAR EN UN ARCHIVO *.CSV
#-------------------------------------------------------------------------------
#convertir los datos a data frame y guardarlos en CSV
data <- as.data.frame(data.b)

{Name.Dir.Lee <- "RF" # Nombre del directorio
  
  {ifelse(!
            dir.exists(file.path(folder,Name.Dir.Lee)),
          dir.create(file.path(folder, Name.Dir.Lee)),
          FALSE)
    dir.RF <- file.path(folder,Name.Dir.Lee)}
}

write.csv(data, file= paste(dir.RF,"DATOS.csv", sep = "/"))
